@@ -1,5 +1,9 @@
 """
-This code is used to add documentation to one or more files. The code uses the OpenAI API to generate a summary of the code.
+This code is used to add documentation to one or more files. The code uses the OpenAI API to generate a summary of the code. The code is divided into two main parts:
+
+    - The first part is the main function, which is used to parse the command line arguments and call the appropriate function.
+
+    - The second part is the subcommands, which are the functions that are called by the main function.
 
 The code uses the following classes and functions:
 
@@ -25,6 +29,8 @@ def main():
 
     parser_add = subparsers.add_parser("add", help="Add documentation to one or more files")
     parser_add.add_argument("files", nargs="+", help="Files to add documentation to")
+    parser_add.add_argument("--no_stage", action="store_true", default=False, help="Don't stage modified files")
+    parser_add.add_argument("--silent", action="store_true", default=False, help="Don't ask for confirmation")
 
 
     parser_set_key = subparsers.add_parser("set-key", help="Set OpenAI key")
