@@ -2,16 +2,22 @@ from src.openai_functions import edit, complete
 import subprocess
 import configparser
 import os
-# This file contains all the functions that are used to interact with the files in the repository
-# It contains the following functions:
-# add: This function is used to add files to the repository. It takes in a list of files and adds them to the repository, documenting them
-# generate_readme: This function is used to generate a readme file for the repository. It uses the openai API to generate a readme file
-# set_key: This function is used to set the openai API key. It takes in the key as an argument and stores it in the .aexconfig file
 
-# This function is used to add files to the repository. It takes in a list of files and adds them to the repository, documenting them
+"""
+This file contains all the functions that are used to interact with the files in the repository
+It contains the following functions:
+add: This function is used to add files to the repository. It takes in a list of files and adds them to the repository, documenting them
+generate_readme: This function is used to generate a readme file for the repository. It uses the openai API to generate a readme file
+set_key: This function is used to set the openai API key. It takes in the key as an argument and stores it in the .aexconfig file
+"""
 
 def add(args):
-    # Iterate over the list of modified files and pass each file to the add_docs function
+    """
+    This function is used to add files to the repository. It takes in a list of files and adds them to the repository, documenting them
+    Parameters:
+    args: The arguments passed to the add command
+    """
+    # Iterate over the list of modified files and pass each file to the edit function
     files = args.files
     max = len(files)
     pointer = 0
@@ -22,12 +28,15 @@ def add(args):
         else:
             with open(files[pointer], 'r') as f:
                 content = f.read()
-            edit(content, output_path=files[pointer])
+            edit(content, output_path=files[pointer], silent=args.silent)
         pointer+=1
-    subprocess.run(["git", "add"]+files)
+    if not args.no_stage:
+        subprocess.run(["git", "add"]+files)
 
 def generate_readme():
-    # This function is used to generate a readme file for the repository. It uses the openai API to generate a readme file
+    """
+    This function is used to generate a readme file for the repository. It uses the openai API to generate a readme file
+    """
     FILES_NOT_TO_INCLUDE = ['LICENSE', 'README.md']
     if os.path.exists('.aexignore'):
         with open('.aexignore', 'r') as f:
@@ -37,7 +46,11 @@ def generate_readme():
     README_START =  f'# {cur_dir_not_full_path}\n## What is it?\n'
 
     def generate_prompt(length=3000):
-        #This function has been borrowed from tom-doerr (https://github.com/tom-doerr/codex-readme)
+        """
+        This function has been borrowed from tom-doerr (https://github.com/tom-doerr/codex-readme)
+        Parameters:
+        length: The length of the prompt to be generated
+        """
         input_prompt = ''
         files_sorted_by_mod_date = sorted(os.listdir('.'), key=os.path.getmtime)
         # Reverse sorted files.
@@ -65,7 +78,11 @@ def generate_readme():
     
 
 def set_key(args):
-    # This function is used to set the openai API key. It takes in the key as an argument and stores it in the .aexconfig file
+    """
+    This function is used to set the openai API key. It takes in the key as an argument and stores it in the .aexconfig file
+    Parameters:
+    args: The arguments passed to the set_key command
+    """
     config = configparser.ConfigParser()
     config.read('.aexconfig')
     if not config.has_section('openai'):
